/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include "badge_log.h"
#include "badge_error.h"
#include "badge_setting.h"
#include "badge_ipc.h"

EXPORT_API int badge_setting_get_pkgname(badge_setting_h setting, char **pkgname)
{
	if (setting == NULL || pkgname == NULL) {
		ERR("Invalid Parameter");
		return BADGE_ERROR_INVALID_PARAMETER;
	}

	if (setting->pkgname == NULL) {
		ERR("setting->pkgname is null");
		return BADGE_ERROR_NOT_EXIST;
	}

	*pkgname = strdup(setting->pkgname);

	return BADGE_ERROR_NONE;
}

EXPORT_API int badge_setting_get_appid(badge_setting_h setting, char **appid)
{
	if (setting == NULL || appid == NULL) {
		ERR("Invalid Parameter");
		return BADGE_ERROR_INVALID_PARAMETER;
	}

	if (setting->appid == NULL) {
		ERR("setting->appid is null");
		return BADGE_ERROR_NOT_EXIST;
	}

	*appid = strdup(setting->appid);

	return BADGE_ERROR_NONE;
}

EXPORT_API int badge_setting_set_allow_to_display(badge_setting_h setting, bool value)
{
	if (setting == NULL) {
		ERR("Invalid Parameter");
		return BADGE_ERROR_INVALID_PARAMETER;
	}

	setting->allow_to_display = value;
	return BADGE_ERROR_NONE;
}

EXPORT_API int badge_setting_get_allow_to_display(badge_setting_h setting, bool *value)
{
	if (setting == NULL || value == NULL) {
		ERR("Invalid Parameter");
		return BADGE_ERROR_INVALID_PARAMETER;
	}

	*value = setting->allow_to_display;
	return BADGE_ERROR_NONE;
}

EXPORT_API int badge_setting_update_setting_for_uid(badge_setting_h setting, uid_t uid)
{
	return badge_ipc_request_update_setting(setting, uid);
}

EXPORT_API int badge_setting_update_setting(badge_setting_h setting)
{
	if (setting == NULL) {
		ERR("Invalid Parameter");
		return BADGE_ERROR_INVALID_PARAMETER;
	}
	return badge_setting_update_setting_for_uid(setting, getuid());
}

EXPORT_API int badge_setting_get_setting_by_appid_for_uid(badge_setting_h *setting, const char *appid, uid_t uid)
{
	return badge_ipc_request_get_setting_by_appid(setting, appid, uid);
}

EXPORT_API int badge_setting_get_setting_by_appid(badge_setting_h *setting, const char *appid)
{
	if (setting == NULL || appid == NULL) {
		ERR("Invalid Parameter");
		return BADGE_ERROR_INVALID_PARAMETER;
	}

	return badge_setting_get_setting_by_appid_for_uid(setting, appid, getuid());
}

EXPORT_API int badge_setting_free_setting(badge_setting_h setting)
{
	if (setting == NULL) {
		ERR("Invalid Parameter");
		return BADGE_ERROR_INVALID_PARAMETER;
	}

	if (setting->pkgname)
		free(setting->pkgname);
	if (setting->appid)
		free(setting->appid);
	free(setting);
	setting = NULL;

	return BADGE_ERROR_NONE;
}
